==> ucs-test_10.0.19-19.tar.gz: ucs-test-10.0.19/univention/testing/browser/udm_users.py <==
#!/usr/bin/python3
#
# -*- coding: utf-8 -*-
#
# Like what you see? Join us!
# https://www.univention.com/about-us/careers/vacancies/
#
# Copyright 2023 Univention GmbH
#
# https://www.univention.de/
#
# All rights reserved.
#
# The source code of this program is made available
# under the terms of the GNU Affero General Public License version 3
# (GNU AGPL V3) as published by the Free Software Foundation.
#
# Binary versions of this program provided by Univention to you as
# well as other copyrighted, protected or trademarked materials like
# Logos, graphics, fonts, specific documentations and configurations,
# cryptographic keys etc. are subject to a license agreement between
# you and Univention and not subject to the GNU AGPL V3.
#
# In the case you use this program under the terms of the GNU AGPL V3,
# the program is provided in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public
# License with the Debian GNU/Linux or Univention distribution in file
# /usr/share/common-licenses/AGPL-3; if not, see
# <https://www.gnu.org/licenses/>.

from dataclasses import dataclass


@dataclass
class User:
    username: str
    lastname: str
    password: str = "univention"
    has_popup_after_login: bool = False


@dataclass
class Users:
    regular_user: User
    admin_user: User


def create_test_user(udm, lo) -> User:
    userdn = udm.create_user()[0]
    user_object = lo.get(userdn)

    return User(
        user_object["uid"][0].decode("utf-8"),
        user_object["sn"][0].decode("utf-8"),
    )

==> ucs-test_10.0.24-36.tar.gz: ucs-test-10.0.24/univention/testing/browser/udm_users.py <==
#!/usr/bin/python3
#
# -*- coding: utf-8 -*-
#
# Like what you see? Join us!
# https://www.univention.com/about-us/careers/vacancies/
#
# Copyright 2023-2024 Univention GmbH
#
# https://www.univention.de/
#
# All rights reserved.
#
# The source code of this program is made available
# under the terms of the GNU Affero General Public License version 3
# (GNU AGPL V3) as published by the Free Software Foundation.
#
# Binary versions of this program provided by Univention to you as
# well as other copyrighted, protected or trademarked materials like
# Logos, graphics, fonts, specific documentations and configurations,
# cryptographic keys etc. are subject to a license agreement between
# you and Univention and not subject to the GNU AGPL V3.
#
# In the case you use this program under the terms of the GNU AGPL V3,
# the program is provided in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public
# License with the Debian GNU/Linux or Univention distribution in file
# /usr/share/common-licenses/AGPL-3; if not, see
# <https://www.gnu.org/licenses/>.

from dataclasses import dataclass


@dataclass
class User:
    username: str
    lastname: str
    password: str = 'univention'
    has_popup_after_login: bool = False


@dataclass
class Users:
    regular_user: User
    admin_user: User


def create_test_user(udm, lo) -> User:
    userdn = udm.create_user()[0]
    user_object = lo.get(userdn)

    return User(
        user_object['uid'][0].decode('utf-8'),
        user_object['sn'][0].decode('utf-8'),
    )
